NLSL: lprmpt.c Source File

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

lprmpt.c
Go to the documentation of this file.
1 /* This is a kludge to work around the fact that VS FORTRAN won't let
2 you write a line to standard output that does not end with a <CR>/<LF>
3 unlike real programming languages.
4 */
5 #include <stdio.h>
6 #include "fortrancall.h"
7
8 void FORTRAN(lprmpt)( void )
9 {
10 fputs( "NLSL> ", stdout );
11 fflush( stdout );
12 }
FORTRAN
#define FORTRAN(n)
Definition: fortrancall.h:8
fortrancall.h
lprmpt
void FORTRAN() lprmpt(void)
Definition: lprmpt.c:8